exceptiontools.UnboundedTimeIntervalError
=========================================

.. abjad-lineage:: abjad.tools.exceptiontools.UnboundedTimeIntervalError.UnboundedTimeIntervalError

.. autoclass:: abjad.tools.exceptiontools.UnboundedTimeIntervalError.UnboundedTimeIntervalError
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.exceptiontools.UnboundedTimeIntervalError.UnboundedTimeIntervalError.__delattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.UnboundedTimeIntervalError.UnboundedTimeIntervalError.__getitem__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.UnboundedTimeIntervalError.UnboundedTimeIntervalError.__getslice__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.UnboundedTimeIntervalError.UnboundedTimeIntervalError.__repr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.UnboundedTimeIntervalError.UnboundedTimeIntervalError.__setattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.UnboundedTimeIntervalError.UnboundedTimeIntervalError.__setstate__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.UnboundedTimeIntervalError.UnboundedTimeIntervalError.__str__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.UnboundedTimeIntervalError.UnboundedTimeIntervalError.__unicode__
   :noindex:
